#!/usr/bin/env python
#
# Copyright 2014 Google Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Saves memory by reusing an already-open font."""

__author__ = "roozbeh@google.com (Roozbeh Pournader)"

from fontTools import ttLib


_font_cache = {}


def open_font(font_file_name):
    """Opens a font using ttLib, returned a cached value if already open."""
    try:
        return _font_cache[font_file_name]
    except KeyError:
        font = ttLib.TTFont(font_file_name)
        _font_cache[font_file_name] = font
        return font
